Method: RubyFFDB::Document#structure

Defined in:
lib/rffdb/document.rb

#structureHash

Returns a copy of the schema information for this class.

Returns:

  • (Hash)

    a copy of the schema information for this class



177
178
179
# File 'lib/rffdb/document.rb', line 177

def structure
  self.class.send(:structure)
end